# 2021-07-27 - Meta Stable Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated due to numerical issues when one of the token depegs. Additionally, price oracles will no longer be maintained.
>
> An updated version of the [Phantom Stable Pool](../20211208-stable-phantom-pool) will soon be released, providing a migration path for existing Pools.

Deployment of the `MetaStablePoolFactory`, for Meta Stable Pools of 2 tokens.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Optimism mainnet address](./output/optimism.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`QueryProcessor` artifact](./artifact/QueryProcessor.json)
- [`MetaStablePoolFactory` artifact](./artifact/MetaStablePoolFactory.json)
